from __future__ import unicode_literals

from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


def get_secure_cache_opts():
    if hasattr(settings, 'DJANGO_REDIS_SECURE_CACHE_NAME'):
        cache_name = settings.DJANGO_REDIS_SECURE_CACHE_NAME
    else:
        cache_name = 'default'

    secure_cache_options_settings = settings.CACHES[cache_name].get('OPTIONS')
    if not secure_cache_options_settings:
            raise ImproperlyConfigured(
                'OPTIONS must be defined in settings in secure cache settings!')
    if secure_cache_options_settings['SERIALIZER'] == 'secure_redis.serializer.SecureSerializer':
        return secure_cache_options_settings


secure_cache_options_settings = get_secure_cache_opts()
if secure_cache_options_settings:
    if not secure_cache_options_settings.get('REDIS_SECRET_KEY'):
        raise ImproperlyConfigured(
            'REDIS_SECRET_KEY must be defined in settings in secure cache OPTIONS')




from __future__ import unicode_literals

import django.test
from django.core import cache

import mock


class SecureRedisTestCase(django.test.TestCase):
    @mock.patch('redis.client.StrictRedis.set')
    @mock.patch('cryptography.fernet.Fernet.encrypt')
    def test_encryption_called(self, encrypt_method, set_method):
        set_method.return_value = True
        original_val = "123"
        redis_cache = cache.caches['default']
        redis_cache.set('val', original_val)
        encrypt_method.assert_called_once()
        set_method.assert_called_once()

    @mock.patch('redis.client.StrictRedis.set')
    @mock.patch('redis.client.StrictRedis.get')
    def test_encryption_flow(self, get_method, set_method):
        original_val = "123"
        set_method.return_value = True
        redis_cache = cache.caches['default']
        redis_cache.set('val', original_val)
        set_method.assert_called_once()

        enc_val = set_method.call_args[0][1]
        self.assertNotEqual(enc_val, original_val)

        get_method.return_value = enc_val
        decrypted_value = redis_cache.get('val')
        self.assertEqual(original_val, decrypted_value)



from django.conf.urls import url

from . import views

urlpatterns = [
    url(r'^$',
        views.stats, name='rq_home'),
    url(r'^queues/(?P<queue_index>[\d]+)/$',
        views.jobs, name='rq_jobs'),
    url(r'^queues/(?P<queue_index>[\d]+)/finished/$',
        views.finished_jobs, name='rq_finished_jobs'),
    url(r'^queues/(?P<queue_index>[\d]+)/started/$',
        views.started_jobs, name='rq_started_jobs'),
    url(r'^queues/(?P<queue_index>[\d]+)/deferred/$',
        views.deferred_jobs, name='rq_deferred_jobs'),
    url(r'^queues/(?P<queue_index>[\d]+)/empty/$',
        views.clear_queue, name='rq_clear'),
    url(r'^queues/(?P<queue_index>[\d]+)/(?P<job_id>[-\w]+)/$',
        views.job_detail, name='rq_job_detail'),
    url(r'^queues/(?P<queue_index>[\d]+)/(?P<job_id>[-\w]+)/delete/$',
        views.delete_job, name='rq_delete_job'),
    url(r'^queues/actions/(?P<queue_index>[\d]+)/$',
        views.actions, name='rq_actions'),
    url(r'^queues/(?P<queue_index>[\d]+)/(?P<job_id>[-\w]+)/requeue/$',
        views.requeue_job_view, name='rq_requeue_job'),
]
